==========
DFTB+ Step
==========

This plug-in exposes the functionality of `DFTB+`_, which is an implementation of the
Density Functional based Tight Binding (DFTB) method, containing many extensions to the
original method. The development is supported by various groups, resulting in a code
which is probably the most versatile DFTB-implementation, with some unique features not
available in other implementations so far.

.. grid:: 1 1 2 2

   .. grid-item-card:: Getting Started
      :margin: 0 3 0 0

      A simple introduction

      .. button-link:: ./getting_started/index.html
	 :color: primary
	 :expand:

         To the Getting Started Guide

   .. grid-item-card::  User Guide
      :margin: 0 3 0 0

      A complete guide to using this step

      .. button-link:: ./user_guide/index.html
	 :color: primary
	 :expand:

         To the User Guide

   .. grid-item-card::  Developer Guide
      :margin: 0 3 0 0

      Contributing to the code. Fixing bugs, adding functionality

      .. button-link:: ./developer_guide/index.html
	 :color: primary
	 :expand:

         To the Developer Guide

   .. grid-item-card:: API Reference
      :margin: 0 3 0 0

      The API for the DFTB+ Step

      .. button-link:: ./api/index.html
	 :color: primary
	 :expand:

	 To the API Reference.


.. toctree::
   :hidden:
   :maxdepth: 1
   :titlesonly:

   getting_started/index
   user_guide/index
   developer_guide/index
   api/index
   DFTB+ documentation <https://dftbplus.org/documentation>

More Information
================
.. toctree::
   :maxdepth: 1
   :titlesonly:

   authors
   history

.. links to software
.. _DFTB+: https://dftbplus.org
   
